import { AnyAction } from 'redux';
import * as actionTypes from '../action_types';
import { OperationAction, DeleteOperationAction, OpId } from '../typedefs';
export declare enum OpsBlueprintActionKey {
    Start = "start",
    Success = "success",
    Error = "error",
    Delete = "delete"
}
export declare type OpsBlueprintActionTypes = {
    readonly START: string;
    readonly SUCCESS: string;
    readonly ERROR: string;
    readonly DELETE: string;
};
export interface OpsBlueprintAction {
    readonly type: string;
    [actionTypes.prefix]: OpsBlueprintActionData;
}
export interface OpsBlueprintActionData extends OpsBlueprintGenericActionData {
    op: OperationAction | DeleteOperationAction;
    action?: OpsBlueprintOriginalAction | null;
}
export interface OpsBlueprintGenericActionData {
    uniqueId?: OpId;
    broadcast?: boolean;
}
export interface OpsBlueprintOriginalAction extends AnyAction {
    [actionTypes.prefix]?: OpsBlueprintGenericActionData;
}
export interface OpsBlueprintActionCreator {
    (data?: any, action?: OpsBlueprintOriginalAction | null): OpsBlueprintAction;
}
declare type OpsBlueprintAnyActionCreator = (data?: any) => any;
export declare type OpsBlueprintActionComposers = {
    [key in OpsBlueprintActionKey]?: OpsBlueprintAnyActionCreator;
};
export declare type OpsBlueprintComposedActionCreator = OpsBlueprintActionCreator | OpsBlueprintAnyActionCreator;
declare type OpsBlueprintActionCreators = {
    [key in Exclude<OpsBlueprintActionKey, OpsBlueprintActionKey.Delete>]: (data?: any) => OpsBlueprintAction;
} & {
    readonly delete: () => OpsBlueprintAction;
};
export declare type OpsBlueprint = {
    readonly id: OpId;
} & OpsBlueprintActionCreators & OpsBlueprintActionTypes;
export declare type OpsBlueprintFn<T extends (...args: any) => any> = (...args: Parameters<T>) => OpsBlueprintAction;
export {};
